Documentation
¶
Index ¶
Constants ¶
const ( StepConnect Step = iota StepSelect StepFilter StepSearch StepTail StepQuit StepPause StepRate StepViewOptions // GaugeUptimeSeconds is the number of seconds the CLI has been running GaugeUptimeSeconds = "cli_uptime_seconds" // CounterExecTotal is the number of times CLI is used. Increment on every start CounterExecTotal = "cli_exec_total" // CounterErrorsTotal is the number of errors that occurred during CLI execution CounterErrorsTotal = "cli_errors_total" // CounterFeaturePauseTotal is the number of times pause feature was used CounterFeaturePauseTotal = "cli_feature_pause_total" // CounterFeatureFilterTotal is the number of times filter feature was used CounterFeatureFilterTotal = "cli_feature_filter_total" // CounterFeatureSearchTotal is the number of times search feature was used CounterFeatureSearchTotal = "cli_feature_search_total" // CounterFeatureViewTotal is the number of times view options feature was used CounterFeatureViewTotal = "cli_feature_view_total" // CounterFeatureSampleTotal is the number of times sample feature was used CounterFeatureSampleTotal = "cli_feature_sample_total" // CounterFeatureSelectTotal is the number of times an audience was selected CounterFeatureSelectTotal = "cli_feature_select_total" // GaugeArgsNum is the number of CLI args passed to the CLI each time it is ran // This is only a count and does not contain the actual args or values GaugeArgsNum = "cli_args_num" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
Step Step
Args []string
// Args specifically used by tail()
TailComponent *TailComponent
TailFilter string
TailSearch string
TailSearchPrev string
TailRate int
TailViewOptions *ViewOptions
TailLineNum int // line num we are at in tail view
}
type TailComponent ¶
TailComponent is used to display audiences in the "select component" view
Click to show internal directories.
Click to hide internal directories.